/************************************************************************/
/*		aISA-A45 Device Driver for Windows 95/NT						*/
/*																		*/
/*			aisa45.h	-	Win32 interface definition					*/
/*			date		-	1998/10/23									*/
/************************************************************************/

#if !defined( AISA45_H )
#define	AISA45_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define AISA45_SUCCESS				0		/* Successfully proccessed */
#define AISA45_ERR_SYSTEM			5001	/* Call GetLastError() */
#define AISA45_ERR_NO_DEVICE		5002	/* No card */
#define AISA45_ERR_IN_USE			5003	/* Device is in use */
#define AISA45_ERR_INVALID_SLOT		5004	/* Invalid slot number */
#define AISA45_ERR_RESOURCE			5005	/* Resource exhaustion */
#define	AISA45_ERR_NO_CREATE		5006	/* Device is not created */
#define AISA45_ERR_INVALID_ARGUMENT	5007	/* Invalid argument */
#define AISA45_ERR_INVALID_COMMAND	5051	/* Invalid command */
#define AISA45_ERR_INVALID_MODE		5052	/* Invalid mode */
#define AISA45_ERR_CHANNEL			5053	/* Invalid channel */
#define AISA45_ERR_TIMER			5054	/* Invalid timer value */
#define AISA45_ERR_BUFFSIZE			5055	/* Bad buffer size */
#define AISA45_ERR_NOT_ENOUGH_MEM	5056	/* Not enough memory */
#define AISA45_ERR_NUMDATA			5057	/* Not enough data */
#define AISA45_ERR_BUSY				5058	/* busy */

/*==============*/
/*	Message ID	*/
/*==============*/
#define WM_EOC							0
#define WM_BUFF_HALF_FULL				1
#define WM_BUFF_FULL					2
#define WM_BUFF_OVERFLOW				3
#define WM_SAMPLING_OVERRUN				4

/*==================*/
/*	Sampling status	*/
/*==================*/
#define AISA45_STS_SAMPLING				0x01
#define AISA45_STS_EOC					0x02
#define AISA45_STS_BUFF_HALF_FULL		0x04
#define AISA45_STS_BUFF_FULL			0x08
#define AISA45_STS_BUFF_OVERFLOW		0x10
#define AISA45_STS_SAMPLING_OVERRUN		0x20

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	AISA45_MAX_SLOTS	16			/* Maximum number of slots */

										/* default search */
#define	AISA45_SLOT_AUTO	( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	AISA45_BOARD_ID		0x0045		/* isa bus device id */
#define	AISA45_VENDOR_ID	0x0000		/* isa bus vendor id */
										/* our device id */
#define	AISA45_DEVICE_ID	( ( DWORD )AISA45_BOARD_ID\
							| ( ( DWORD )AISA45_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	AISA45_MAX_MEM		9			/* number of memory windows */
#define	AISA45_MAX_IO		20			/* number of i/o windows */
#define	AISA45_MAX_IRQ		7			/* number of irqs */
#define	AISA45_MAX_DMA		7			/* number of dmas */

typedef	struct	_AISA45RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[AISA45_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[AISA45_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[AISA45_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[AISA45_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[AISA45_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Num IRQs */
	DWORD	dwIRQRegisters	[AISA45_MAX_IRQ];	/* IRQ */
	DWORD	dwIRQAttrib		[AISA45_MAX_IRQ];	/* IRQ attribute */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[AISA45_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[AISA45_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} AISA45RESOURCE, *PAISA45R;

/*==================================*/
/*	Sampling parameter structure	*/
/*==================================*/
typedef struct _AISA45MODE {
	DWORD	dwMode;								/* Sampling mode */
	DWORD	dwChFirst;							/* Start channel */
	DWORD	dwChLast;							/* End channel */
	DWORD	cwBuffer;							/* Buffer size */
	DWORD	dwTimer;							/* Timer value */
} AISA45MODE, *PAISA45MODE;

#if !defined( AISA45_DRIVER )
#define	AISA45_API

#if !defined( AISA45_DLL )
	#define AISA45LIB_API	extern __declspec( dllimport )
#else
	#define AISA45LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

AISA45LIB_API BOOL	WINAPI	Aisa45GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
AISA45LIB_API BOOL	WINAPI	Aisa45Create( PWORD pwLogSlot, HWND hwnd, UINT uWMBase );
AISA45LIB_API BOOL	WINAPI	Aisa45Close( WORD wLogSlot );
AISA45LIB_API BOOL	WINAPI	Aisa45GetResource( WORD wLogSlot, PAISA45R pres );
AISA45LIB_API BOOL	WINAPI	Aisa45SetMode( WORD wLogSlot, PAISA45MODE pcmode );
AISA45LIB_API BOOL	WINAPI	Aisa45StartSampling( WORD wLogSlot );
AISA45LIB_API BOOL	WINAPI	Aisa45StopSampling( WORD wLogSlot );
AISA45LIB_API BOOL	WINAPI	Aisa45GetSamplingStatus( WORD wLogSlot, PDWORD pcwNumData, PDWORD pdwStatus );
AISA45LIB_API BOOL	WINAPI	Aisa45GetData( WORD wLogSlot, DWORD cwNumData, PWORD pwData );
AISA45LIB_API BOOL	WINAPI	Aisa45InPort( WORD wLogSlot, PBYTE pbInValue );
AISA45LIB_API DWORD	WINAPI	Aisa45GetLastError( WORD wLogSlot );

#endif	/* #if !defined( AISA45_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( AISA45_H ) */

/**/